@@ -2,9 +2,11 @@ from flask import Flask
 from flask_restful import Api
 from flask_cors import CORS
 from python_helper import Constant as c
-from python_helper import log, Function, ReflectionHelper, ObjectHelper, StringHelper, SettingHelper
+from python_helper import log, Function, ReflectionHelper, ObjectHelper, StringHelper
 import globals
 from python_framework.api.src.constant import ControllerConstant
+from python_framework.api.src.constant import ConfigurationKeyConstant
+from python_framework.api.src.constant import StaticConstant
 from python_framework.api.src.util import FlaskUtil
 from python_framework.api.src.service.flask import FlaskManager
 from python_framework.api.src.service import SqlAlchemyProxy
@@ -13,7 +15,6 @@ from python_framework.api.src.service import ApiKeyManager
 from python_framework.api.src.service import SecurityManager
 from python_framework.api.src.service import SchedulerManager
 from python_framework.api.src.service.openapi import OpenApiManager
-from python_framework.api.src.constant import ConfigurationKeyConstant
 
 
 DOT_PY = '.py'
@@ -136,10 +137,7 @@ def getBaseUrl(globalsInstance):
 def getStaticBaseUrl(staticPackage, givenBaseStaticUrl, globalsInstance):
     if ObjectHelper.isNotEmpty(givenBaseStaticUrl):
         return givenBaseStaticUrl
-    staticPathUri = f'{c.FOWARD_SLASH}{staticPackage}'
-    if SettingHelper.activeEnvironmentIsLocal():
-        return staticPathUri
-    return f'{getBaseUrl(globalsInstance)}{staticPathUri}'
+    return f'{getBaseUrl(globalsInstance)}{c.FOWARD_SLASH}{staticPackage}'
 
 
 @Function
@@ -155,8 +153,8 @@ def initialize(
     rootName,
     refferenceModel,
     managerList = None,
-    staticPackage = 'static',
-    viewsPackage = 'views',
+    staticPackage = StaticConstant.KW_STATIC_FOLDER,
+    viewPackage = StaticConstant.KW_VIEW_FOLDER,
     staticUrl = None,
     **kwargs
 ):
